@@ -16,24 +16,44 @@
 from gi.repository import Gio, GLib
 
 
-LOLLYPOP_DATA_PATH = GLib.get_user_data_dir() + "/lollypop"
-
 App = Gio.Application.get_default
 
+LASTFM_API_KEY = "7a9619a850ccf7377c46cf233c51e3c6"
+LASTFM_API_SECRET = "9254319364d73bec6c59ace485a95c98"
+
+DISCOGS_API_KEY = "vcKgyONtKsaQZLvpUfOU"
+DISCOGS_API_SECRET = "SmWphfGWALsmDnoyhPuQlDDQEIvFJuPM"
+
 GOOGLE_API_ID = "015987506728554693370:waw3yqru59a"
 
-TAG_EDITORS = ["kid3-qt", "exfalso", "easytag", "picard", "puddletag"]
-
+MARGIN_BIG = 30
 MARGIN = 15
 MARGIN_MEDIUM = 10
 MARGIN_SMALL = 5
 
+LOLLYPOP_DATA_PATH = GLib.get_user_data_dir() + "/lollypop"
 # All cache goes here
 CACHE_PATH = GLib.get_user_cache_dir() + "/lollypop"
-# Fallback when album dir is readonly
-STORE_PATH = GLib.get_user_data_dir() + "/lollypop/store"
-# Store for Web
-TMP_PATH = GLib.get_user_data_dir() + "/lollypop/tmp"
+# Stores for albums
+ALBUMS_PATH = LOLLYPOP_DATA_PATH + "/albums"
+ALBUMS_WEB_PATH = LOLLYPOP_DATA_PATH + "/albums_web"
+# Stores for artists
+ARTISTS_PATH = LOLLYPOP_DATA_PATH + "/artists"
+# Store for lyrics
+LYRICS_PATH = LOLLYPOP_DATA_PATH + "/lyrics"
+
+
+class TimeStamp:
+    ONE_YEAR = 31536000
+    TWO_YEAR = 63072000
+    THREE_YEAR = 94608000
+
+
+class FileType:
+    UNKNOWN = 0
+    AUDIO = 1
+    PLS = 2
+    OTHER = 3
 
 
 class Repeat:
@@ -59,6 +79,8 @@ class StorageType:
     SPOTIFY_SIMILARS = 1 << 5
     EXTERNAL = 1 << 6
     SEARCH = 1 << 7
+    DEEZER_CHARTS = 1 << 8
+    ALL = 1 << 1 | 1 << 2 | 1 << 3 | 1 << 4 | 1 << 5 | 1 << 6 | 1 << 7 | 1 << 8
 
 
 class ArtBehaviour:
@@ -93,6 +115,7 @@ class ViewType:
     PLAYBACK = 1 << 12
     BANNER = 1 << 13
     ARTIST = 1 << 14
+    TOOLBAR = 1 << 15
 
 
 NetworkAccessACL = {
@@ -103,14 +126,16 @@ NetworkAccessACL = {
     "GOOGLE": 1 << 5,
     "STARTPAGE": 1 << 6,
     "WIKIPEDIA": 1 << 7,
-    "TUNEIN": 1 << 8,
+    #    "TUNEIN": 1 << 8,
     "MUSICBRAINZ": 1 << 9,
     "ITUNES": 1 << 10,
     "DEEZER": 1 << 11,
     "WIKIA": 1 << 12,
     "GENIUS": 1 << 13,
     "AUDIODB": 1 << 14,
-    "FANARTTV": 1 << 15
+    "FANARTTV": 1 << 15,
+    "DUCKDUCKGO": 1 << 16,
+    "LIBREFM": 1 << 17
 }
 
 
@@ -197,8 +222,8 @@ class Size:
     PHONE = 360  # Librem Phone
     SMALL = 500
     MEDIUM = 720
-    NORMAL = 1000
-    BIG = 1300
+    NORMAL = 850
+    BIG = 1000
 
 
 class OrderBy:
