@@ -15,11 +15,10 @@ from gi.repository import Gtk, Gdk, GLib, GObject, Pango
 from locale import strcoll
 
 from lollypop.view_lazyloading import LazyLoadingView
-from lollypop.helper_filtering import FilteringHelper
 from lollypop.helper_gestures import GesturesHelper
 from lollypop.fastscroll import FastScroll
 from lollypop.define import Type, App, ArtSize, SelectionListMask
-from lollypop.define import ArtBehaviour, ViewType
+from lollypop.define import ArtBehaviour, ViewType, StorageType
 from lollypop.logger import Logger
 from lollypop.utils import get_icon_name, on_query_tooltip, popup_widget
 from lollypop.utils import emit_signal
@@ -197,7 +196,7 @@ class SelectionListRow(Gtk.ListBoxRow):
             Return True if populated
             @return bool
         """
-        return True
+        return self.get_child() is not None
 
     @property
     def name(self):
@@ -241,15 +240,15 @@ class SelectionListRow(Gtk.ListBoxRow):
         else:
             self.__artwork.get_style_context().remove_class("circle-icon")
             self.__artwork.set_from_surface(surface)
+            del surface
         emit_signal(self, "populated")
 
 
-class SelectionList(FilteringHelper, LazyLoadingView, GesturesHelper):
+class SelectionList(LazyLoadingView, GesturesHelper):
     """
         A list for artists/genres
     """
     __gsignals__ = {
-        "populated": (GObject.SignalFlags.RUN_FIRST, None, ()),
         "expanded": (GObject.SignalFlags.RUN_FIRST, None, (bool,))
     }
 
@@ -258,8 +257,7 @@ class SelectionList(FilteringHelper, LazyLoadingView, GesturesHelper):
             Init Selection list ui
             @param base_mask as SelectionListMask
         """
-        LazyLoadingView.__init__(self, ViewType.DEFAULT)
-        FilteringHelper.__init__(self)
+        LazyLoadingView.__init__(self, StorageType.ALL, ViewType.DEFAULT)
         self.__selection_pending_ids = []
         self.__base_mask = base_mask
         self.__mask = SelectionListMask.NONE
@@ -276,6 +274,7 @@ class SelectionList(FilteringHelper, LazyLoadingView, GesturesHelper):
         self.__scrolled.add(self.__viewport)
         self.__viewport.show()
         self.__viewport.add(self._box)
+        self.connect("initialized", self.__on_initialized)
         if self.__base_mask & SelectionListMask.VIEW:
             self.__overlay = Gtk.Overlay.new()
             self.__overlay.set_hexpand(True)
@@ -351,6 +350,7 @@ class SelectionList(FilteringHelper, LazyLoadingView, GesturesHelper):
         child = self._get_child(value)
         child.populate()
         if self.mask & SelectionListMask.ARTISTS:
+            self.__fastscroll.clear()
             self.__fastscroll.populate()
 
     def update_value(self, object_id, name):
@@ -560,12 +560,12 @@ class SelectionList(FilteringHelper, LazyLoadingView, GesturesHelper):
         """
         self.__base_mask &= ~(SelectionListMask.LABEL |
                               SelectionListMask.ELLIPSIZE)
-        if status or self.mask & SelectionListMask.VIEW:
+        if status or self.__base_mask & SelectionListMask.VIEW:
             self.__base_mask |= (SelectionListMask.LABEL |
                                  SelectionListMask.ELLIPSIZE)
         elif App().settings.get_value("show-sidebar-labels"):
             self.__base_mask |= SelectionListMask.LABEL
-        self.__set_rows_mask(self.__base_mask)
+        self.__set_rows_mask(self.__base_mask | self.__mask)
 
     def _on_map(self, widget):
         """
@@ -609,18 +609,6 @@ class SelectionList(FilteringHelper, LazyLoadingView, GesturesHelper):
         """
         self.__popup_menu(y)
 
-    def _on_initial_loading(self):
-        """
-            Update fastscroll and scroll to first item
-        """
-        if self.mask & SelectionListMask.ARTISTS:
-            self.__fastscroll.populate()
-        emit_signal(self, "populated")
-        # Scroll to first selected item
-        for row in self._box.get_selected_rows():
-            GLib.idle_add(self._scroll_to_child, row)
-            break
-
 #######################
 # PRIVATE             #
 #######################
@@ -664,29 +652,33 @@ class SelectionList(FilteringHelper, LazyLoadingView, GesturesHelper):
                 b = row_b.name
             return strcoll(a, b)
 
-    def __popup_menu(self, y=None, row=None):
+    def __popup_menu(self, y=None, relative=None):
         """
             Show menu at y or row
             @param y as int
             @param relative as Gtk.Widget
         """
         if self.__base_mask & SelectionListMask.SIDEBAR:
-            from lollypop.menu_selectionlist import SelectionListMenu
-            from lollypop.widgets_menu import MenuBuilder
-            if row is None:
-                row = self._box.get_row_at_y(y)
-                if row is None:
-                    return
-                row_id = row.id
-            else:
-                row_id = None
-            menu = SelectionListMenu(self,
-                                     row_id,
-                                     self.mask,
-                                     App().window.is_adaptive)
-            menu_widget = MenuBuilder(menu)
-            menu_widget.show()
-            popup_widget(menu_widget, row)
+            menu = None
+            row_id = None
+            if relative is None:
+                relative = self._box.get_row_at_y(y)
+                if relative is not None:
+                    row_id = relative.id
+            if row_id is None:
+                from lollypop.menu_selectionlist import SelectionListMenu
+                menu = SelectionListMenu(self,
+                                         self.mask,
+                                         App().window.is_adaptive)
+            elif not App().settings.get_value("save-state"):
+                from lollypop.menu_selectionlist import SelectionListRowMenu
+                menu = SelectionListRowMenu(row_id,
+                                            App().window.is_adaptive)
+            if menu is not None:
+                from lollypop.widgets_menu import MenuBuilder
+                menu_widget = MenuBuilder(menu)
+                menu_widget.show()
+                popup_widget(menu_widget, relative, None, None, None)
 
     def __on_artist_artwork_changed(self, object, value):
         """
@@ -711,3 +703,15 @@ class SelectionList(FilteringHelper, LazyLoadingView, GesturesHelper):
             @param value as str
         """
         self._on_adaptive_changed(App().window, App().window.is_adaptive)
+
+    def __on_initialized(self, selectionlist):
+        """
+            Update fastscroll
+            @param selectionlist as SelectionList
+        """
+        if self.mask & SelectionListMask.ARTISTS:
+            self.__fastscroll.populate()
+        # Scroll to first selected item
+        for row in self._box.get_selected_rows():
+            GLib.idle_add(self._scroll_to_child, row)
+            break
