@@ -16,17 +16,19 @@ from gettext import gettext as _
 
 from lollypop.view import View
 from lollypop.define import App, ViewType, AdaptiveSize
-from lollypop.define import StorageType
+from lollypop.define import StorageType, LYRICS_PATH
 from lollypop.logger import Logger
+from lollypop.utils import get_network_available
 from lollypop.objects_track import Track
 from lollypop.helper_lyrics import LyricsHelper
 from lollypop.helper_signals import SignalsHelper, signals_map
 from lollypop.widgets_banner_lyrics import LyricsBannerWidget
+from lollypop.information_store import InformationStore
 
 
 class LyricsLabel(Gtk.Stack):
     """
-        Lyrics label with effect on change
+        Lyrics label with crossfade on change
     """
 
     def __init__(self):
@@ -47,22 +49,28 @@ class LyricsLabel(Gtk.Stack):
         self.add(self.__label1)
         self.add(self.__label2)
         self.set_transition_type(Gtk.StackTransitionType.CROSSFADE)
-        self.set_transition_duration(200)
+        self.set_transition_duration(250)
 
-    def set_text(self, text):
+    def set_text(self, text, crossfade=False):
         """
             Set label text
             @param text as str
+            @param crossfade as bool
         """
-        self.next()
+        if crossfade:
+            self.next()
         self.get_visible_child().set_text(text)
 
-    def set_markup(self, markup):
+    def set_markup(self, markup, crossfade=False):
         """
             Set label markup
             @param markup as str
+            @param crossfade as bool
         """
-        self.next()
+        if self.get_visible_child().get_label() == markup:
+            return
+        if crossfade:
+            self.next()
         self.get_visible_child().set_markup(markup)
 
     def next(self):
@@ -84,11 +92,13 @@ class LyricsView(View, SignalsHelper):
 
     # TODO add https://www.musixmatch.com support
     @signals_map
-    def __init__(self):
+    def __init__(self, view_type):
         """
             Init view
+            @param view_type as ViewType
         """
-        View.__init__(self, ViewType.SCROLLED | ViewType.OVERLAY)
+        View.__init__(self, StorageType.COLLECTION,
+                      view_type | ViewType.OVERLAY)
         self.__lyrics_timeout_id = None
         self.__downloads_running = 0
         self.__lyrics_text = ""
@@ -97,12 +107,13 @@ class LyricsView(View, SignalsHelper):
         self.__lyrics_label = LyricsLabel()
         self.__lyrics_label.show()
         self.__lyrics_label.set_property("halign", Gtk.Align.CENTER)
-        self.__banner = LyricsBannerWidget(self._view_type)
+        self.__banner = LyricsBannerWidget(self.view_type)
         self.__banner.show()
         self.__banner.connect("translate", self.__on_translate)
         self.add_widget(self.__lyrics_label, self.__banner)
         self.__lyrics_helper = LyricsHelper()
         self.__update_lyrics_style()
+        self.__information_store = InformationStore()
         return [
                 (App().window, "adaptive-size-changed",
                  "_on_adaptive_size_changed"),
@@ -115,8 +126,8 @@ class LyricsView(View, SignalsHelper):
             @param track as Track
         """
         self.__banner.translate_button.set_sensitive(False)
-        self.__lyrics_label.set_text("")
         if track.id is None:
+            self.__lyrics_label.set_text("")
             return
         self.__lyrics_label.set_text(_("Loading…"))
         lyrics = ""
@@ -126,7 +137,7 @@ class LyricsView(View, SignalsHelper):
             if self.__lyrics_helper.available:
                 if self.__lyrics_timeout_id is None:
                     self.__lyrics_timeout_id = GLib.timeout_add(
-                        500, self.__show_sync_lyrics)
+                        200, self.__show_sync_lyrics)
                 return
             else:
                 if self.__lyrics_timeout_id is not None:
@@ -145,11 +156,21 @@ class LyricsView(View, SignalsHelper):
                         lyrics = tagreader.get_lyrics(tags)
         if lyrics:
             self.__lyrics_label.set_text(lyrics)
+            self.__lyrics_text = lyrics
         else:
-            self.__lyrics_helper.get_lyrics_from_web(track,
-                                                     self.__on_lyrics,
-                                                     False,
-                                                     track)
+            name = track.name + track.album.name + ",".join(track.artists)
+            content = self.__information_store.get_information(name,
+                                                               LYRICS_PATH)
+            if content:
+                self.__lyrics_label.set_text(content.decode("utf-8"))
+            elif not get_network_available():
+                self.__lyrics_label.set_text(
+                    _("Network unavailable or disabled in settings"))
+            else:
+                self.__lyrics_helper.get_lyrics_from_web(track,
+                                                         self.__on_lyrics,
+                                                         False,
+                                                         track)
 
     @property
     def args(self):
@@ -203,22 +224,28 @@ class LyricsView(View, SignalsHelper):
         """
             Show sync lyrics for track
         """
-        timestamp = App().player.position / 1000000
+        timestamp = App().player.position
         (previous, current, next) =\
-            self.__lyrics_helper.get_lyrics_for_timestamp(timestamp)
+            self.__lyrics_helper.get_lyrics_for_timestamp(timestamp + 200)
         lyrics = ""
-        for line in previous:
-            if line:
+        for line in previous[:-1]:
+            if line.strip():
                 escaped = GLib.markup_escape_text(line)
                 lyrics += "<span alpha='20000'>%s</span>" % escaped + "\n"
+        lyrics += "\n"
+        for line in previous[-1:]:
+            if line.strip():
+                escaped = GLib.markup_escape_text(line)
+                lyrics += "<span alpha='35000'>%s</span>" % escaped + "\n"
         for line in current:
-            escaped = GLib.markup_escape_text(line)
-            lyrics += "<span>%s</span>" % escaped + "\n"
-        for line in next:
-            if line:
+            if line.strip():
                 escaped = GLib.markup_escape_text(line)
-                lyrics += "<span alpha='20000'>%s</span>" % escaped + "\n"
-        self.__lyrics_label.set_markup(lyrics)
+                lyrics += "<span>%s</span>" % escaped + "\n"
+        for line in next:
+            if line.strip():
+                escaped = GLib.markup_escape_text(line)
+                lyrics += "<span alpha='35000'>%s</span>" % escaped + "\n"
+        self.__lyrics_label.set_markup(lyrics, True)
         return True
 
     def __get_blob(self, text):
@@ -275,7 +302,7 @@ class LyricsView(View, SignalsHelper):
         """
         if lyrics is None:
             self.__lyrics_label.set_text(
-                    _("Network not available"))
+                    _("Disabled in network settings"))
         elif lyrics == "":
             if filtered:
                 self.__lyrics_label.set_text(_("No lyrics found ") + "😓")
@@ -290,4 +317,9 @@ class LyricsView(View, SignalsHelper):
                                                          track)
         else:
             self.__lyrics_label.set_text(lyrics)
+            self.__lyrics_text = lyrics
+            name = track.name + track.album.name + ",".join(track.artists)
+            self.__information_store.save_information(name,
+                                                      LYRICS_PATH,
+                                                      lyrics.encode("utf-8"))
             self.__banner.translate_button.set_sensitive(True)
